@@ -48,7 +48,10 @@ class Circle(Model):
         rdf_type = 'hd:circle'
 
     def __str__(self):
-        return self.name
+        try:
+            return '{} ({})'.format(self.name, self.urlid)
+        except:
+            return self.urlid
 
     def get_admins(self):
         return self.members.filter(is_admin=True)
@@ -60,7 +63,10 @@ class CircleMember(Model):
     is_admin = models.BooleanField(default=False)
 
     def __str__(self):
-        return str(self.pk)
+        try:
+            return '{} -> {} ({})'.format(self.circle.urlid, self.user.urlid, self.urlid)
+        except:
+            return self.urlid
 
     class Meta(Model.Meta):
         container_path = "circle-members/"
